@@ -59,7 +59,7 @@ class Aria2TUI:
     def add_graph_to_options(self) -> None:
         """ Add the transmission speed graphs to the menu options. """
         self.download_options.append(
-            Option("Transfer Speed Graph *experimental*", graph_speeds_gid, {
+            Option("Transfer Speed Graph", graph_speeds_gid, {
                 "stdscr": self.stdscr,
                 "get_data_function": lambda gid: sendReq(tellStatus(gid)),
 
@@ -74,9 +74,11 @@ class Aria2TUI:
                 "title": "Download Transfer Speeds",
             }),
         )
+        options_names = [[option.name] for option in self.download_options]
+        self.dl_operations_data["items"] = options_names
 
         self.menu_options.append(
-            Option("Transfer Speed Graph *experimental*", graph_speeds, {
+            Option("Transfer Speed Graph (Global)", graph_speeds, {
                 "stdscr": self.stdscr,
                 "get_data_function": lambda: sendReq(getGlobalStat()),
                 "graph_wh" : lambda: (
@@ -88,6 +90,10 @@ class Aria2TUI:
                 "title": "Global Transfer Speeds",
             }),
         )
+        # self.menu_data["items"] = [[menu_option.name] for menu_option in self.menu_options],
+        menu_names = [[option.name] for option in self.menu_options]
+        self.menu_data["items"] = menu_names
+        # MenuPicker.set_function_data(self.menu_data)
 
     def check_and_refresh_terminal_options(self, menu_option: Option, stdscr: curses.window):
         if "refresh_terminal_options" in menu_option.meta_args and menu_option.meta_args["refresh_terminal_options"]:
@@ -97,14 +103,17 @@ class Aria2TUI:
 
     def run(self) -> None:
         """ Run Aria2TUI app loop. """
+        DownloadsPicker = Picker(self.stdscr, **self.downloads_data)
+        DownloadsPicker.load_input_history("~/.config/aria2tui/cmdhist.json")
+        MenuPicker = Picker(self.stdscr, **self.menu_data)
+        DownloadOperationPicker = Picker(self.stdscr, **self.dl_operations_data)
         while True:
             ## SELECT DOWNLOADS
-            DownloadsPicker = Picker(self.stdscr, **self.downloads_data)
             selected_downloads, opts, self.downloads_data = DownloadsPicker.run()
+            # When going back to the Downloads picker after selecting a download it shouldn't wait to get new data before displaying the picker
+            DownloadsPicker.get_data_startup = False
 
             if selected_downloads:
-                operation_names = [option.name for option in self.download_options]
-                self.dl_operations_data["items"] = operation_names
 
                 items, header = self.downloads_data["items"], self.downloads_data["header"]
                 gid_index, fname_index = header.index("GID"), header.index("Name")
@@ -112,12 +121,25 @@ class Aria2TUI:
                 fnames = [item[fname_index] for i, item in enumerate(items) if i in selected_downloads]
 
                 # Display the download names in an infobox when selecting which operation to perform
-                self.dl_operations_data["display_infobox"] = True
-                self.dl_operations_data["infobox_items"] = fnames
-                self.dl_operations_data["infobox_title"] = f"{len(fnames)} Selected..."
+                # self.dl_operations_data["display_infobox"] = True
+                # self.dl_operations_data["infobox_items"] = [[f] for f in fnames]
+                # self.dl_operations_data["infobox_title"] = f"{len(fnames)} Selected..."
+
+                # Display the download names in a right pane
+                self.dl_operations_data["right_panes"] = [
+                    {
+                        "proportion": 2/3,
+                        "auto_refresh": False,
+                        "get_data": lambda data, state: [],
+                        "display": right_split_display_list,
+                        "data": ["Selected...", fnames],
+                        "refresh_time": 1.0,
+                    },
+                ]
+                self.dl_operations_data["split_right"] = True
 
                 ## SELECT OPERATION TO APPLY TO SELECTED DOWNLOADS
-                DownloadOperationPicker = Picker(self.stdscr, **self.dl_operations_data)
+                DownloadOperationPicker.set_function_data(self.dl_operations_data)
                 selected_operation, opts, self.dl_operations_data = DownloadOperationPicker.run()
                 if selected_operation:
                     operation = download_options[selected_operation[0]]
@@ -138,14 +160,13 @@ class Aria2TUI:
 
             else: 
 
-                self.menu_data["items"] = [menu_option.name for menu_option in self.menu_options]
                 while True:
                     ## SELECT MENU OPTION
-                    MenuPicker = Picker(self.stdscr, **self.menu_data)
                     selected_menu, opts, self.menu_data = MenuPicker.run()
 
                     # If we exit from the menu then exit altogether
                     if not selected_menu: 
+                        DownloadsPicker.save_input_history("~/.config/aria2tui/cmdhist.json")
                         close_curses(self.stdscr)
                         return 
 
@@ -214,27 +235,30 @@ def display_message(stdscr: curses.window, msg: str) -> None:
 
 def handleAriaStartPromt(stdscr):
     ## Check if aria is running
-    curses.init_pair(1, curses.COLOR_WHITE, curses.COLOR_BLACK)
-    stdscr.bkgd(' ', curses.color_pair(1))  # Apply background color
+    curses.init_pair(2, curses.COLOR_WHITE, curses.COLOR_BLACK)
+    stdscr.bkgd(' ', curses.color_pair(2))  # Apply background color
     stdscr.refresh()
     config = get_config()
 
     colour_theme_number=config["appearance"]["theme"]
+
+    header, choices = ["Aria2c Connection Down. Do you want to start it?"], ["Yes", "No"]
+    connect_data = {
+        "items": choices,
+        "title": "Aria2TUI",
+        "header": header,
+        "max_selected": 1,
+        "colour_theme_number": colour_theme_number,
+        "number_columns": False,
+    }
+    ConnectionPicker = Picker(stdscr, **connect_data)
+    ConnectionPicker.splash_screen("Testing Aria2 Connection")
+
     while True:
         connection_up = testConnection()
         can_connect = testAriaConnection()
         if not can_connect:
             if not connection_up:
-                header, choices = ["Aria2c Connection Down. Do you want to start it?"], ["Yes", "No"]
-                connect_data = {
-                    "items": choices,
-                    "title": "Aria2TUI",
-                    "header": header,
-                    "max_selected": 1,
-                    "colour_theme_number": colour_theme_number,
-                    "number_columns": False,
-                }
-                ConnectionPicker = Picker(stdscr, **connect_data)
 
                 choice, opts, function_data = ConnectionPicker.run()
 
@@ -243,30 +267,16 @@ def handleAriaStartPromt(stdscr):
                     exit()
 
                 config = get_config()
-
-                h, w = stdscr.getmaxyx()
-                if (h>8 and w >20):
-                    s = "Starting Aria2c Now..."
-                    stdscr.addstr(h//2-1, (w-len(s))//2, s)
-                    s = f'startupcmds = {config["general"]["startupcmds"]}'
-                    stdscr.addstr(h//2+1, (w-min(len(s), w))//2, s[:w])
-                    stdscr.refresh()
+                ConnectionPicker.splash_screen("Starting Aria2c Now...")
 
                 for cmd in config["general"]["startupcmds"]:
                     subprocess.Popen(cmd, shell=True, stderr=subprocess.PIPE, stdout=subprocess.PIPE)
 
                 time.sleep(2)
             else:
-                h, w = stdscr.getmaxyx()
-                if (h>8 and w >20):
-                    s = "The connection is up but unresponsive..."
-                    stdscr.addstr(h//2, (w-len(s))//2, s)
-                    s="Is your token correct in config.toml?"
-                    stdscr.addstr(h//2+1, (w-len(s))//2, s)
-                    stdscr.refresh()
-                    stdscr.timeout(5000)
-                    stdscr.getch()
-                close_curses(stdscr)
+                ConnectionPicker.splash_screen(["The connection is up but unresponsive...", "Is your token correct in your aria2tui.toml?"])
+                stdscr.timeout(5000)
+                stdscr.getch()
                 exit()
         else:
             break
