@@ -16,6 +16,10 @@ from aria2tui.lib.aria2c_wrapper import *
 from aria2tui.utils.aria2c_utils import *
 from aria2tui.graphing.speed_graph import graph_speeds, graph_speeds_gid
 from aria2tui.ui.aria2tui_keys import download_option_keys, menu_keys, aria2tui_keys
+from aria2tui.graphing.pane_graph import get_dl_data, right_split_dl_graph
+from aria2tui.graphing.pane_graph_progress import get_dl_progress, right_split_dl_progress_graph
+from aria2tui.graphing.pane_pieces import right_split_piece_progress, get_dl_pieces
+from aria2tui.graphing.pane_files import right_split_files, get_dl_files
 
 from listpick.listpick_app import *
 
@@ -27,6 +31,8 @@ colour_theme_number=config["appearance"]["theme"]
 app_name = "Aria2TUI"
 global_stats_timer = config["general"]["global_stats_timer"]
 refresh_timer = config["general"]["refresh_timer"]
+show_graph = config["appearance"]["show_right_pane_default"]
+right_pane_index = config["appearance"]["right_pane_default_index"]
 
 class Option:
     def __init__(self, name: str, function: Callable, function_args:dict = {}, meta_args: dict = {}):
@@ -54,7 +60,7 @@ download_options = [
     Option("Remove (paused)", remove),
     # Option("forceRemove", forceRemove),
     # Option("removeStopped", removeDownloadResult),
-    Option("Remove (errored)", removeDownloadResult),
+    Option("Remove (errored/completed)", removeDownloadResult),
 
 
     Option("DL Info: Files", getFiles, {}, {"picker_view":True}),
@@ -101,8 +107,7 @@ menu_data = {
     "title": app_name,
     "colour_theme_number": colour_theme_number,
     "max_selected": 1,
-    "items": [menu_option.name for menu_option in menu_options],
-    #*******
+    "items": [[menu_option.name] for menu_option in menu_options],
     "header": ["Main Menu    "],
     "centre_in_terminal": True,
     "centre_in_cols": False,
@@ -112,6 +117,7 @@ menu_data = {
     "keys_dict": menu_keys,
     "show_footer": False,
     "number_columns": False,
+    "cell_cursor": False,
 }
 downloads_data = {
     "top_gap": 0,
@@ -136,6 +142,55 @@ downloads_data = {
     "keys_dict": aria2tui_keys,
     "footer_string_refresh_function": getGlobalSpeed,
     "footer_timer": global_stats_timer,
+    "cell_cursor": False,
+
+    "split_right": show_graph,
+    "right_panes": [
+        # DL files
+        {
+            "proportion": 1/2,
+            "display": right_split_files,
+            "get_data": get_dl_files,
+            "data": [],
+            "auto_refresh": True,
+            "refresh_time": 0.2,
+        },
+        # DL transfer speed graph
+        {
+            "proportion": 3/5,
+            "display": right_split_dl_graph,
+            "get_data": get_dl_data,
+            "data": [],
+            "auto_refresh": True,
+            "refresh_time": 1.0,
+        },
+        # DL progress graph
+        {
+            "proportion": 3/5,
+            "display": right_split_dl_progress_graph,
+            "get_data": get_dl_progress,
+            "data": [],
+            "auto_refresh": True,
+            "refresh_time": 1.0,
+        },
+        # DL Pieces
+        {
+            "proportion": 2/3,
+            "display": right_split_piece_progress,
+            "get_data": get_dl_pieces,
+            "data": [],
+            "auto_refresh": True,
+            "refresh_time": 1.0,
+        },
+    ],
+    "right_pane_index": right_pane_index,
+    # "split_right_function": right_split_dl_graph,
+    # "split_right_refresh_data": get_dl_data,
+    # "split_right_proportion": 2/3,
+    # "split_right_auto_refresh": True,
+    # "split_right_refresh_data_timer": 1.0,
+    # "split_right_function": right_split_dl_progress_graph,
+    # "split_right_refresh_data": get_dl_progress,
 }
 dl_operations_data = {
     "top_gap": 0,
@@ -149,4 +204,5 @@ dl_operations_data = {
     "keys_dict": download_option_keys,
     "cancel_is_back": True,
     "number_columns": False,
+    "cell_cursor": False,
 }
