@@ -20,6 +20,7 @@ os.chdir(os.path.dirname(os.path.realpath(__file__)))
 import tempfile
 import tabulate
 from typing import Callable, Tuple
+import re
 
 
 from aria2tui.lib.aria2c_wrapper import *
@@ -61,7 +62,20 @@ def te(url: str = "http://localhost", port: int = 6800) -> bool:
         return False
 
 def getOptionAndFileInfo(gids: list[str]) -> Tuple[list, list]:
-    """ Get option and file info for each GID. Used for fetching download data for Picker rows. """
+    """ 
+    Get option and file info for each GID. Used for fetching download data for Picker rows.
+    We split the gid requests into batches of 2000 to ensure that we get a resposne.
+    """
+    options_batch = []
+    files_info_batch = []
+    for i in range(len(gids)//2000 + 1):
+        tmp_options_batch, tmp_files_info_batch = getOptionAndFileInfoBatch(gids[i*2000:(i+1)*2000])
+        options_batch += tmp_options_batch
+        files_info_batch += tmp_files_info_batch
+    return options_batch, files_info_batch
+
+def getOptionAndFileInfoBatch(gids: list[str]) -> Tuple[list, list]:
+    """ Batch-get option and file info for each GID. Used for fetching download data for Picker rows. """
     options_batch = []
     files_info_batch = []
     # for i in range(len(js_rs["result"])):
@@ -433,6 +447,8 @@ def addUrisFull(url: str ="http://localhost", port: int =6800, token: str = None
 
         uri = dl["uri"]
         download_options_dict = {key: val for key,val in dl.items() if key in valid_keys}
+        if "dir" in download_options_dict:
+            download_options_dict["dir"] = os.path.expandvars(os.path.expanduser(download_options_dict["dir"]))
         # return_val, gid = addDownload(**{key:val for key,val in dl.items() if key in valid_keys})
         return_val, gid = addDownload(uri, download_options_dict=download_options_dict)
         if return_val:
@@ -620,7 +636,16 @@ def getAll() -> Tuple[list[list[str]], list[str]]:
     stopped, sheader = getStopped()
     waiting, wheader = getQueue()
 
-    return active + waiting + stopped, wheader
+    dir_index = wheader.index("DIR")
+    all = active + waiting + stopped, wheader
+    home = "/home/" + os.getlogin()
+    for row in all[0]:
+
+        if row[dir_index].startswith(home):
+            row[dir_index] = "~" + row[dir_index][len(home):]
+
+
+    return all
 
 def openDownloadLocation(gid: str, new_window: bool = True) -> None:
     """ Opens the download location for a given download. """
@@ -800,6 +825,8 @@ def applyToDownloads(stdscr: curses.window, gids: list = [], operation_name: str
             l = []
             for i, response in enumerate(responses):
                 l += [[gid, "------"]]
+                if "result" in response: response = response["result"]
+                response = process_dl_dict(response)
                 l += [[key, val] for key, val in flatten_data(response).items()]
             x = Picker(
                 stdscr,
@@ -813,6 +840,15 @@ def applyToDownloads(stdscr: curses.window, gids: list = [], operation_name: str
 
     stdscr.clear()
 
+def process_dl_dict(dls):
+    if "result" in dls:
+        dls = dls["result"]
+    for dl in dls:
+        for key in dl:
+            if key in ["length", "completedLength"]:
+                dl[key] = bytes_to_human_readable(dl[key])
+    return dls
+
 def getGlobalSpeed() -> str:
     resp = sendReq(getGlobalStat())
     up = bytes_to_human_readable(resp['result']['uploadSpeed'])
@@ -873,7 +909,9 @@ def get_default_config() -> dict:
             "launch_command": "xdg-open",
         },
         "appearance":{
-            "theme": 0
+            "theme": 3,
+            "show_right_pane_default": False,
+            "right_pane_default_index": 0,
         }
     }
     return default_config
